@@ -259,7 +259,11 @@ class OSCClientTestBase(base.ClientTestBase):
 
     def create_share_access_rule(self, share, access_type,
                                  access_to, properties=None,
-                                 access_level=None, wait=False):
+                                 access_level=None, wait=False,
+                                 lock_visibility=False,
+                                 lock_deletion=False,
+                                 lock_reason=None,
+                                 add_cleanup=False):
         cmd = f'access create {share} {access_type} {access_to} '
 
         if access_level:
@@ -267,7 +271,13 @@ class OSCClientTestBase(base.ClientTestBase):
         if properties:
             cmd += f'--properties {properties} '
         if wait:
-            cmd += f'--wait'
+            cmd += '--wait '
+        if lock_visibility:
+            cmd += '--lock-visibility '
+        if lock_deletion:
+            cmd += '--lock-deletion '
+        if lock_reason:
+            cmd += f'--lock-reason {lock_reason}'
 
         access_rule = self.dict_result('share', cmd)
 
@@ -416,3 +426,49 @@ class OSCClientTestBase(base.ClientTestBase):
 
         check_result = self.dict_result('share', cmd)
         return check_result
+
+    def create_resource_lock(self, resource_id, resource_type='share',
+                             resource_action='delete', lock_reason=None,
+                             add_cleanup=True, client=None):
+
+        cmd = f'lock create {resource_id} {resource_type}'
+        cmd += f' --resource-action {resource_action}'
+
+        if lock_reason:
+            cmd += f' --reason "{lock_reason}"'
+
+        lock = self.dict_result('share', cmd, client=client)
+
+        if add_cleanup:
+            self.addCleanup(self.openstack,
+                            'share lock delete %s' % lock['id'],
+                            client=client)
+        return lock
+
+    def create_backup(self, share_id, name=None, description=None,
+                      backup_options=None, add_cleanup=True):
+
+        name = name or data_utils.rand_name('autotest_backup_name')
+
+        cmd = (f'backup create {share_id} ')
+
+        if name:
+            cmd += f' --name {name}'
+        if description:
+            cmd += f' --description {description}'
+        if backup_options:
+            options = ' --backup-options'
+            for key, value in backup_options.items():
+                options += f' {key}={value}'
+            cmd += options
+
+        backup_object = self.dict_result('share', cmd)
+        self._wait_for_object_status(
+            'share backup', backup_object['id'], 'available')
+
+        if add_cleanup:
+            self.addCleanup(
+                self.openstack,
+                f'share backup delete {backup_object["id"]} --wait')
+
+        return backup_object
